@@ -41,6 +41,12 @@ class ListTransactionsV1Request:
         self.realDestinationAccountType = None
         # Filter out custom transaction amounts, excluding transaction records below a certain amount specified in USD from the query results
         self.hideSmallAmountUsd = None
+        # Filter transaction history by transaction direction:
+        # Default: Retrieve all types of transactions
+        # INFLOW: Retrieve inflows
+        # OUTFLOW: Retrieve outflows
+        # INTERNAL_TRANSFER: Retrieve internal transfers
+        self.transactionDirection = None
 
 
 class ListTransactionsV2Request:
@@ -85,6 +91,12 @@ class ListTransactionsV2Request:
         self.realDestinationAccountType = None
         # Filter out custom transaction amounts, excluding transaction records below a certain amount specified in USD from the query results
         self.hideSmallAmountUsd = None
+        # Filter transaction history by transaction direction:
+        # Default: Retrieve all types of transactions
+        # INFLOW: Retrieve inflows
+        # OUTFLOW: Retrieve outflows
+        # INTERNAL_TRANSFER: Retrieve internal transfers
+        self.transactionDirection = None
 
 
 class CreateTransactionRequest:
@@ -125,6 +137,10 @@ class CreateTransactionRequest:
         self.destinationAccountType = None
         # If the destinationAccountType is ONE_TIME_ADDRESS, then this field should have a value
         self.destinationAddress = None
+        # The memo (up to 100 characters) for the destination address, also known as a comment or tag. This parameter is valid for transactions on the following networks:
+        # TON: TON mainnet
+        # TON_TESTNET: TON testnet
+        self.memo = None
         # Destination Tag
         self.destinationTag = None
         # Bitcoin enabled for RBF (Replace-by-fee is a protocol in the Bitcoin mempool that allows for the replacement of an unconfirmed transaction with another one)
@@ -239,6 +255,11 @@ class OneTransactionsRequest:
         # Merchant unique business ID (100 characters max)
         self.customerRefId = None
 
+class ApprovalDetailTransactionsRequest:
+    def __init__(self):
+        # Transaction key list within 20 transaction keys
+        self.txKeyList = None
+
 
 class TransactionsFeeRateRequest:
     def __init__(self):
@@ -345,6 +366,11 @@ class TransactionApi:
     def one_transactions(self, request: OneTransactionsRequest):
         return self.api_client.send_request(request, '/v1/transactions/one')
 
+    # Retrieve Transaction Approval Details
+    # Query approval details of a transaction. Exclusively for transactions using the new advanced transaction policy. Learn more about new advanced transaction policies.
+    def approval_detail_transactions(self, request: ApprovalDetailTransactionsRequest):
+        return self.api_client.send_request(request, '/v1/transactions/approvalDetail')
+
     # Estimate Transaction Fee
     # This interface provides users with an estimated range of transaction fee rates of a given cryptocurrency when creating or speeding up transactions.
     def transaction_fee_rate(self, request: TransactionsFeeRateRequest):
